#!/bin/sh

export SBOX_DIR=/scratchbox
export SBOX_LOGIN=$SBOX_DIR/login

SBOFFSET=$SBOX_DIR/users/`whoami`
SBHOME=$SBOFFSET/home/`whoami`

tdir=`mktemp -d $SBHOME/test.XXXXXX` || exit 1
status=0

if [ x$1 = x ]; then
	tests="test-*.sh"
else
	tests=$1
fi

for test in $tests
do
	name=`head -n1 $test | grep '^#' | cut -c3-`
	if [ x"$name" = x ]
	then
		name=`echo $test | cut -d- -f2- | cut -d. -f1 | tr - ' ' | tr _ ' '`
	fi

	echo -n "Running \"$name\" ... " >&2
	cp $test $tdir
	echo "cd ${tdir/$SBOFFSET} ; sh ./$test" | $SBOX_LOGIN /bin/sh -s > $tdir/out 2> $tdir/err
	retval=$?

	if [ $retval -eq 0 ]
	then
		echo "OK" >&2
	else
		echo "FAIL" >&2
		status=1
	fi

	if [ `stat -c %s $tdir/out` -ne 0 ]
	then
		echo -n 'Output:'
		sed 's/^/\t/' $tdir/out
	fi

	if [ `stat -c %s $tdir/err` -ne 0 ]
	then
		echo -n 'Errors:'
		sed 's/^/\t/' $tdir/err
	fi
done

rm -r $tdir
exit $status
