#!/bin/bash

# binfmt_misc
if [ ! -d /proc/sys/fs/binfmt_misc ]; then
	echo "Host kernel is lacking binfmt_misc support!"
	echo "You need it to run scratchbox."
	exit 1
fi
					

# ip_local_port_range

if cat /proc/sys/net/ipv4/ip_local_port_range | awk '{ exit ! ($2-$1 < 10000) }'; then 
    echo "Host kernel has port range under 10000."
    echo "This causes problems with fakeroot."
    echo "You can fix this eg. by running:"
    echo '  echo "1024 65000" > /proc/sys/net/ipv4/ip_local_port_range'    
    exit 1
fi

# sanity checks

# check if SBOX_DIR is set, login uses a different variable (why?)
if [ "z$SBOX_DIR" != "z" ] ; then
	if [ ! -e "${SBOX_DIR}/host_shared/lib/ld.so" ] ; then
		echo "Missing ${SBOX_DIR}/host_shared/lib/ld.so"
		echo "Scratchbox-libs not installed?"
		exit 1
	fi
	COMPILERS=`ls -1 "${SBOX_DIR}/compilers" | grep -v '^bin$'`
	if [ "z$COMPILERS" = "z" ] ; then
		echo "You should install at least one toolchain"
		exit 1
	fi
fi
