#!/usr/bin/env python
#
# Copyright (c) 2004 Nokia
# Author: Timo Savola <tsavola@movial.fi>
#
# Licensed under GPL, see COPYING for details.
#

import os, sys, optparse

sys.path += [os.path.dirname(os.path.realpath(sys.argv[0])) + "/../lib/python2.3"]

from sb import config

def usage():
	print "Usage: sb-conf <ACTION> [<OPTIONS>]"
	print
	print "     ACTION  OPTIONS                  ACTION  OPTIONS"
	print "     ------  -------                  ------  -------"
	print
	print "      setup  [<TARGET>]                   st  [<TARGET>]"
	print "             [--compiler=<COMPILER>]          [-c <COMPILER>]"
	print "             [--devkits=<LIST>]               [-d <LIST]"
	print "             [--cputransp=<METHOD>]           [-t <METHOD]"
	print "             [--force]                        [-f]"
	print
	print "    install  [<TARGET>]                   in  [<TARGET>]"
	print "             [--clibrary]                     [-c]"
	print "             [--cruntime]                     [-C]"
	print "             [--etc]                          [-e]"
	print "             [--devkits]                      [-d]"
	print "             [--fakeroot]                     [-F]"
	print "             [--gdb]                          [-G]"
	print "             [--debug-links]                  [-L]"
	print "             [--strace]                       [-S]"
	print
	print "  rootstrap  [<TARGET>]                   rs  [<TARGET>]"
	print "             <FILE>|<URL>                     <FILE>|<URL>"
	print
	print "     select  [<TARGET>]                   se  [<TARGET>]"
	print
	print "      reset  [<TARGET>]                   re  [<TARGET>]"
	print "             [--force]                        [-f]"
	print
	print "    killall  [--signal=<SIGNAL>]          ka  [-s <SIGNAL>]"
	print
	print "     remove  [<TARGET>]                   rm  [<TARGET>]"
	print "             [--force]                        [-f]"
	print
	print "       show  [<TARGET>]                   sh  [<TARGET>]"
	print "             [--compiler]                     [-c]"
	print "             [--compiler-arch]                [-A]"
	print "             [--compiler-subarch]             [-S]"
	print "             [--compiler-clib]                [-C]"
	print "             [--devkits]                      [-d]"
	print "             [--cputransp]                    [-t]"
	print
	print "       list  [--compilers]                ls  [-c]"
	print "             [--devkits]                      [-d]"
	print "             [--cputransps]                   [-t]"
	print "             [--targets]                      [-T]"
	print "             [--sessions]                     [-S]"
	print
	print "    current                               cu"
	print
	print "    version                               ve"
	print
	print "See 'sb-menu' for interactive versions of these actions."
	sys.exit(1)

class OptionParser (optparse.OptionParser):
	def print_usage(self, file = None):
		usage()

	def print_help(self, file = None):
		usage()

if len(sys.argv) < 2:
	usage()

action = sys.argv[1]
params = sys.argv[2:]

parser = OptionParser()

def parse():
	opts, args = parser.parse_args(params)
	if len(args) > 1:
		usage()
	if len(args) == 1:
		return args[0], opts
	return None, opts

def parse_target():
	if len(params) > 1:
		usage()
	elif len(params) == 1:
		return params[0]
	return None

try:
	if action == "setup" or action == "st":
		parser.add_option("-c", "--compiler")
		parser.add_option("-d", "--devkits")
		parser.add_option("-t", "--cputransp")
		parser.add_option("-f", "--force",    action="store_true")
		target, opts = parse()

		if opts.devkits:
			devkits = config.processable(opts.devkits, "").split(":")
		else:
			devkits = None

		if opts.cputransp:
			cputransp = config.processable(opts.cputransp, "")
		else:
			cputransp = None

		config.setup(target, opts.compiler, devkits, cputransp, opts.force)

	elif action == "install" or action == "in":
		parser.add_option("-c", "--clibrary",    action="store_true")
		parser.add_option("-C", "--cruntime",    action="store_true")
		parser.add_option("-e", "--etc",         action="store_true")
		parser.add_option("-d", "--devkits",     action="store_true")
		parser.add_option("-F", "--fakeroot",    action="store_true")
		parser.add_option("-G", "--gdb",         action="store_true")
		parser.add_option("-L", "--debug-links", action="store_true")
		parser.add_option("-S", "--strace",      action="store_true")
		target, opts = parse()

		tools = []
		if opts.fakeroot:
			tools.append("fakeroot")
		if opts.gdb:
			tools.append("gdb")
		if opts.strace:
			tools.append("strace")

		config.install(target, opts.clibrary, opts.cruntime, opts.etc, opts.devkits, opts.debug_links, tools)

	elif action == "rootstrap" or action == "rs":
		if len(params) < 1 or len(params) > 2:
			usage()

		if len(params) == 2:
			target = params[0]
			rootstrap = params[1]
		else:
			target = None
			rootstrap = params[0]

		if rootstrap.find("://") >= 0:
			config.rootstrap(target, url=rootstrap)
		else:
			config.rootstrap(target, path=rootstrap)

	elif action == "select" or action == "se":
		config.select(parse_target())

	elif action == "reset" or action == "re":
		parser.add_option("-f", "--force", action="store_true")
		target, opts = parse()

		config.reset(target, opts.force)

	elif action == "killall" or action == "ka":
		parser.add_option("-s", "--signal",type="int",action="store")
		target, opts = parse()
		if opts.signal:
			config.killall(opts.signal)
		else:
			config.killall()

	elif action == "remove" or action == "rm":
		parser.add_option("-f", "--force", action="store_true")
		target, opts = parse()

		config.remove(target, opts.force)

	elif action == "mount" or action == "mo":
		config.mount(parse_target())

	elif action == "umount" or action == "um":
		config.umount(parse_target())

	elif action == "show" or action == "sh":
		parser.add_option("-c", "--compiler",  action="store_true")
		parser.add_option("-d", "--devkits",   action="store_true")
		parser.add_option("-t", "--cputransp", action="store_true")
		parser.add_option("-A", "--compiler-arch",    action="store_true")
		parser.add_option("-S", "--compiler-subarch", action="store_true")
		parser.add_option("-C", "--compiler-clib",    action="store_true")
		target, opts = parse()

		all = not opts.compiler and not opts.devkits and not opts.cputransp and \
		      not opts.compiler_arch and not opts.compiler_subarch and not opts.compiler_clib

		targetinfo = config.get_target_info(target)
		if not targetinfo:
			if not target:
				target = config.current()
			raise config.Error("Invalid target: " + target)

		compinfo = config.get_compiler_info(targetinfo.compiler)
		if not compinfo:
			raise config.Error("Invalid compiler: " + targetinfo.compiler)

		if opts.compiler or all:
			if all:
				print "Compiler:",
			if not compinfo.prefixedInstall and all:
				print '%s (legacy)'%targetinfo.compiler
			else:
				print targetinfo.compiler

		if opts.devkits or all:
			if all:
				print "Devkits:",
			print config.printable(config.flatten(targetinfo.devkits, " "))

		if opts.cputransp or all:
			if all:
				print "CPU-transparency:",
			print config.printable(targetinfo.cputransp)


		if opts.compiler_arch:
			print compinfo.arch

		if opts.compiler_subarch:
			print compinfo.subarch

		if opts.compiler_clib:
			print compinfo.clib

	elif action == "list" or action == "ls":
		parser.add_option("-c", "--compilers",  action="store_true")
		parser.add_option("-d", "--devkits",    action="store_true")
		parser.add_option("-t", "--cputransps", action="store_true")
		parser.add_option("-T", "--targets",    action="store_true")
		parser.add_option("-S", "--sessions",   action="store_true")
		target, opts = parse()

		if opts.compilers:
			for name in config.list_compilers():
				print name

		if opts.devkits:
			for name in config.list_devkits():
				print name

		if opts.cputransps:
			for devkit in config.list_devkits():
				if config.list_cputransps([devkit]):
					for name in config.list_cputransps([devkit]):
						print os.path.join(config.devkits_dir, devkit, "bin", name)

		if opts.targets:
			for name in config.list_targets():
				print name

		if opts.sessions:
			sessions=config.list_sessions()
			for name in sessions:
				sys.stdout.write("%s:\t" % name)
				for pid in sessions[name]:
					sys.stdout.write("%s " % pid )
				sys.stdout.write("\n")

	elif action == "current" or action == "cu":
		print config.current()

	elif action == "version" or action == "ve":
		print config.version()

	else:
		usage()

except config.Error, e:
	sys.stderr.write("sb-conf: %s\n" % str(e))
	sys.exit(1)

